Piquasso
********


Piquasso is an open source Python package, which allows you to simulate a photonic
quantum computer. One could use Gaussian or Fock state corresponding to different
representations to run simulations.


Installation
============

One could easily install Piquasso with the following command:

.. code-block:: bash

   pip install piquasso


.. toctree::
   :maxdepth: 3
   :caption: Tutorials:
   :hidden:

   tutorials/getting-started
   tutorials/separating-programs
   tutorials/boson-sampling
   tutorials/gaussian-boson-sampling
   tutorials/pure-fock-tensorflow

.. toctree::
   :maxdepth: 3
   :caption: Simulators:
   :hidden:

   simulators/gaussian
   simulators/fock
   simulators/sampling
   simulators/tensorflow

.. toctree::
   :maxdepth: 3
   :caption: States:
   :hidden:

   states/gaussian
   states/fock
   states/sampling

.. toctree::
   :maxdepth: 3
   :caption: Instructions:
   :hidden:

   instructions/preparations
   instructions/gates
   instructions/measurements
   instructions/channels

.. toctree::
   :maxdepth: 3
   :caption: API:
   :hidden:

   api/program
   api/simulator
   api/computer
   api/mode
   api/state
   api/instruction
   api/result
   api/exceptions
